# Shadowsocks(R) utils

[![PyPi Version](http://img.shields.io/pypi/v/ssr-utils.svg)](https://pypi.python.org/pypi/ssr-utils/)

[>> Read the docs <<](https://neoctobers.readthedocs.io/en/latest/repo/py_ssr_utils.html)

